from data_mod import DataMod
import sys
import os
import time
import datetime
import cdo as cdop
import copy
from scipy.io.netcdf import *
from dateutil.relativedelta import *
import numpy as np
from common import *
import glob
import shutil
from set_output_name import *

class DataAtlCMIP5(DataMod):
     """ classe of data for the CMIP5 data
     """
     def __init__(self, varname):
         DataMod.__init__(self, "AtlCMIP5", varname)
         self._nmember=1
         self._freq=relativedelta(months=+1)
         self._filetype="nc"

     def duplicate(self):
          """copy all atribute except the lists"""
          exp2=DataAtlCMIP5("")
          exp2.set_varname(self.get_varname())
          exp2.set_dataname(self.get_dataname())
          exp2.set_freq(self.get_freq())
          exp2.set_inputdir(self.get_inputdir())
          exp2.set_outputdir(self.get_outputdir())
          exp2.set_nmember(self.get_nmember())
          return exp2


     def set_inputdirAuto(self):
          """look for input and output directory corresponding to the dataname"""
          dataname=self.get_dataname() 
          varname=self.get_varname() 
          self.set_inputdir("/esnas/scratch/Earth/CMIP5/"+varname)

     def set_files(self):
          """create the Filelist with the different models"""
          inputdir=self.get_inputdir()
          
          filelist=glob.glob(inputdir+"/*")
          filelist.sort()
          nbfiles=len(filelist)
          datelist=[datetime.date(1,1,1)]*nbfiles
          
          self.set_filelist(filelist)
          self.set_sdates(datelist)


     def set_outputdirAuto(self):
          """defining the path to look for the model daily data"""
          dataname=self.get_dataname()
          varname=self.get_varname()
         
          outputdir = "/esnas/scratch/Earth/CMIP5/statistics/"

          if (not os.path.isdir(outputdir)):
               os.makedirs(outputdir)
               print "Created directory:"
               print outputdir

          self.set_outputdir(outputdir)

   
     def ready(self):
          """create the file to be ready to work on cdo"""

          varname=self.get_varname()
          self.set_inputdirAuto()
          self.set_outputdirAuto() #look for the output directory
          self.set_files()
          self.see()
     
     def getvalues(self):
        """to get value from the different file of the object"""
        cdo=cdop.Cdo()
        #nco = Nco()

        #get the needed variables from the object
        filelist=self.get_filelist()
        nbexp=len(filelist)
        sdates=self.get_sdates()
        dataname=self.get_dataname()
        varname=self.get_varname()
        nmember=self.get_nmember()
        filetype=self.get_filetype()
        varbase=varname.split("_")[0]

        values=[] #np.zeros(nbexp)
        expnamelst=[]
        for iexp in range(nbexp):
            f=filelist[iexp]
            ncdfin=nc.Dataset(f, "r")
            #values[iexp]=ncdfin.variables[varname][:][0]
            values.append(ncdfin.variables[varname][:])
            expname=f.replace(varname,"").replace(".nc","").split(varbase+"_")[-1]
            expnamelst.append(expname)
        return(expnamelst,values)
